@@ -15,7 +15,6 @@
 #include <ktoolinvocation.h>
 
 K_PLUGIN_FACTORY(KonqAboutPageFactory, registerPlugin<KonqAboutPage>();)
-K_EXPORT_PLUGIN(KonqAboutPageFactory("konqaboutpage"))
 
 Q_GLOBAL_STATIC(KonqAboutPageSingleton, s_staticData)
 
@@ -206,7 +205,7 @@ QString KonqAboutPageSingleton::specs()
                     "extra support for other common usability features that arise as "
                     "de facto standards across the Internet. Along with this support, "
                     "for such functions as favicons, Web Shortcuts, and <A HREF=\"%1\">XBEL bookmarks</A>, "
-                    "Konqueror also implements:", QStringLiteral("http://pyxml.sourceforge.net/topics/xbel/")))
+                    "Konqueror also implements:", QStringLiteral("http://xbel.sourceforge.net/")))
           .arg(i18n("Web Browsing"))
           .arg(i18n("Supported standards"))
           .arg(i18n("Additional requirements*"))
@@ -220,12 +219,11 @@ QString KonqAboutPageSingleton::specs()
           .arg(i18n("JavaScript disabled (globally). Enable JavaScript <A HREF=\"%1\">here</A>.", QStringLiteral("exec:/kcmshell5 khtml_java_js")))
           .arg(i18n("JavaScript enabled (globally). Configure JavaScript <A HREF=\\\"%1\\\">here</A>.", QStringLiteral("exec:/kcmshell5 khtml_java_js")))   // leave the double backslashes here, they are necessary for javascript !
           .arg(i18n("Secure <A HREF=\"%1\">Java</A><SUP>&reg;</SUP> support", QStringLiteral("http://www.oracle.com/technetwork/java/index.html")))
-          .arg(i18n("JDK 1.2.0 (Java 2) compatible VM (<A HREF=\"%1\">IBM</A> or <A HREF=\"%2\">Sun/Oracle</A>)",
-                    QStringLiteral("http://www.ibm.com"), QStringLiteral("http://www.oracle.com/technetwork/java/index.html")))
+          .arg(i18n("JDK 1.2.0 (Java 2) compatible VM (<A HREF=\"%1\">OpenJDK</A> or <A HREF=\"%2\">Sun/Oracle</A>)",
+                    QStringLiteral("http://openjdk.java.net/"), QStringLiteral("http://www.oracle.com/technetwork/java/index.html")))
           .arg(i18n("Enable Java (globally) <A HREF=\"%1\">here</A>.", QStringLiteral("exec:/kcmshell5 khtml_java_js")))   // TODO Maybe test if Java is enabled ?
-          .arg(i18n("Netscape Communicator<SUP>&reg;</SUP> <A HREF=\"%4\">plugins</A> (for viewing <A HREF=\"%1\">Flash<SUP>&reg;</SUP></A>, <A HREF=\"%2\">Real<SUP>&reg;</SUP></A>Audio, <A HREF=\"%3\">Real<SUP>&reg;</SUP></A>Video, etc.)",
-                    QStringLiteral("http://www.macromedia.com/shockwave/download/index.cgi?P1_Prod_Version=ShockwaveFlash"),
-                    QStringLiteral("http://www.real.com"), QStringLiteral("http://www.real.com"),
+          .arg(i18n("NPAPI <A HREF=\"%2\">plugins</A> (for viewing <A HREF=\"%1\">Flash<SUP>&reg;</SUP></A>, etc.)",
+                    QStringLiteral("https://get.adobe.com/flashplayer/"),
                     QStringLiteral("about:plugins")))
           .arg(i18n("built-in"))
           .arg(i18n("Secure Sockets Layer"))
@@ -243,7 +241,7 @@ QString KonqAboutPageSingleton::specs()
           .arg(i18n("Transfer protocols"))
           .arg(i18n("HTTP 1.1 (including gzip/bzip2 compression)"))
           .arg(i18n("FTP"))
-          .arg(i18n("and <A HREF=\"%1\">many more (see Kioslaves in KHelpcenter)...</A>", QStringLiteral("exec:/khelpcenter")))
+          .arg(i18n("and <A HREF=\"%1\">many more (see Kioslaves in KHelpCenter)...</A>", QStringLiteral("exec:/khelpcenter")))
           .arg(i18nc("A feature of Konqueror", "URL-Completion"))
           .arg(i18n("Manual"))
           .arg(i18n("Popup"))
@@ -383,7 +381,7 @@ KonqAboutPage::~KonqAboutPage()
 
 bool KonqAboutPage::openUrl(const QUrl &u)
 {
-    emit started(0);
+    emit started(nullptr);
     if (u.url() == QLatin1String("about:plugins")) {
         serve(s_staticData->plugins(), QStringLiteral("plugins"));
     } else if (u.url() == QLatin1String("about:konqueror/intro")) {
