@@ -27,7 +27,8 @@
 #include <QUrl>
 
 #include <kparts/plugin.h>
-#include <kparts/listingextension.h>
+#include <KParts/ListingFilterExtension>
+#include <KParts/ListingNotificationExtension>
 
 class QPushButton;
 class KFileItemList;
@@ -42,8 +43,8 @@ class FilterBar : public QWidget
     Q_OBJECT
 
 public:
-    explicit FilterBar(QWidget *parent = Q_NULLPTR);
-    virtual ~FilterBar();
+    explicit FilterBar(QWidget *parent = nullptr);
+    ~FilterBar() override;
     void selectAll();
 
     QMenu *typeFilterMenu();
@@ -62,8 +63,8 @@ Q_SIGNALS:
     void closeRequest();
 
 protected:
-    void showEvent(QShowEvent *event) Q_DECL_OVERRIDE;
-    void keyReleaseEvent(QKeyEvent *event) Q_DECL_OVERRIDE;
+    void showEvent(QShowEvent *event) override;
+    void keyReleaseEvent(QKeyEvent *event) override;
 
 private:
     KLineEdit *m_filterInput;
@@ -102,7 +103,7 @@ class DirFilterPlugin : public KParts::Plugin
 public:
 
     DirFilterPlugin(QObject *parent, const QVariantList &);
-    ~DirFilterPlugin();
+    ~DirFilterPlugin() override;
 
 private Q_SLOTS:
     void slotReset();
@@ -121,7 +122,7 @@ private:
     void setFilterBar();
 
     struct MimeInfo {
-        MimeInfo() : action(0), useAsFilter(false) {}
+        MimeInfo() : action(nullptr), useAsFilter(false) {}
 
         QAction *action;
         bool useAsFilter;
