@@ -282,14 +282,14 @@ void RectDrawing::drawBack(QPainter *p, DrawParams *dp)
     QRect r = _rect;
     QColor normal = dp->backColor();
     if (dp->selected()) {
-        normal = normal.light();
+        normal = normal.lighter();
     }
     bool isCurrent = dp->current();
 
     if (dp->drawFrame() || isCurrent) {
         // 3D raised/sunken frame effect...
-        QColor high = normal.light();
-        QColor low = normal.dark();
+        QColor high = normal.lighter();
+        QColor low = normal.darker();
         p->setPen(isCurrent ? low : high);
         p->drawLine(r.left(), r.top(), r.right(), r.top());
         p->drawLine(r.left(), r.top(), r.left(), r.bottom());
@@ -1083,7 +1083,7 @@ void TreeMapItem::addItem(TreeMapItem *i)
 
     _children->append(i); // preserve insertion order
     if (sorting(nullptr) != -1) {
-        qSort(_children->begin(), _children->end(), treeMapItemLessThan);
+        std::sort(_children->begin(), _children->end(), treeMapItemLessThan);
     }
 }
 
@@ -1154,7 +1154,7 @@ void TreeMapItem::setSorting(int textNo, bool ascending)
     _sortTextNo = textNo;
 
     if (_children && _sortTextNo != -1) {
-        qSort(_children->begin(), _children->end(), treeMapItemLessThan);
+        std::sort(_children->begin(), _children->end(), treeMapItemLessThan);
     }
 }
 
@@ -1165,7 +1165,7 @@ void TreeMapItem::resort(bool recursive)
     }
 
     if (_sortTextNo != -1) {
-        qSort(_children->begin(), _children->end(), treeMapItemLessThan);
+        std::sort(_children->begin(), _children->end(), treeMapItemLessThan);
     }
 
     if (recursive)
